@@ -1,11 +1,12 @@
 //#include <QDebug>
 
 #include "completer.h"
+#include "mapview/mapview.h"
 
-TCompleter::TCompleter(QList< QPair<QString,QColor> > data,QLineEdit *parent)
- : QObject(parent), editor(parent), list(data)
+TCompleter::TCompleter(TMapView *map,QLineEdit *parent)
+ : QObject(parent), editor(parent)
 {
-
+ list=map->getNamesAndColors();
  popup = new QTreeWidget(parent);
  popup->setWindowFlags(Qt::Popup);
  popup->setFocusPolicy(Qt::NoFocus);
@@ -29,10 +30,8 @@ TCompleter::TCompleter(QList< QPair<QString,QColor> > data,QLineEdit *parent)
  timer->setInterval(500);
  connect(timer, SIGNAL(timeout()), SLOT(autoSuggest()));
  connect(editor, SIGNAL(textEdited(QString)), timer, SLOT(start()));
-
-// connect(&networkManager, SIGNAL(finished(QNetworkReply*)),
-//         this, SLOT(handleNetworkData(QNetworkReply*)));
-
+ connect(this, SIGNAL(doneCompletionByID(int)),map, SLOT(findTrackByID(int)));
+ connect(this, SIGNAL(doneSuggestByID(QList<int>)),map, SLOT(findedNodesToFront(QList<int>)));
 }
 
 TCompleter::~TCompleter()
