@@ -15,34 +15,33 @@
 #include "settings.h"
 #include "ui_details.h"
 #include "details.h"
+#include "about.h"
 
 #include "mapview/mapview.h"
 #include "mapview/mapnode.h"
 #include "completer.h"
 #include "mobileui.h"
+#include "flickcharm.h"
 
 //#if defined(Q_WS_MAEMO_5)
 //#include "fullscreenexitbutton.h"
 //#endif
 
-#define VERSION " 0.5"
-#define URL_MAPS "http://pmetro.su/Maps.html"  //V transparent V
+QString VERSION=" 0.5.1";
+QString URL_MAPS="http://pmetro.su/Maps.html";
+QString URL_TRANSLATE="http://translate.google.com/translate?sl=ru&tl=%1&u=%2";
+
 char ICONSIZE=24; // begin size 100% scale
-QString TOOLBAR_STYLE=    //"QToolBar{border:0px;background:transparent;} QToolBar::separator{width:20px;height:20px;background:transparent;} "
-                      "QToolButton, QToolButton:pressed, QLabel, QLineEdit {border:2px solid grey;border-radius:5px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #dadbde, stop: 1 #f6f7fa);}"
-                      "QToolButton{height: %1px;width: %1px;background-color: transparent;margin-top:4px;margin-left:4px;} "
-                      "QToolButton:pressed{ margin-top:5px;margin-left:5px; }"
-                      "QLabel{color:black;font-weight:bold;padding:2px;}"
-                      "QLineEdit{height:%1px;font-weight:bold;margin-top:2px;margin-left:2px;}";
+QString TOOLBAR_STYLE=
+  "QToolButton,QToolButton:pressed,QLabel,QLineEdit{border:2px solid grey;border-radius:5px;background-color:qlineargradient(x1:0,y1:0,x2:0,y2:1,stop:0 #dadbde,stop:1 #f6f7fa);} "
+  "QToolButton{height:%1px;width:%1px;background-color:transparent;margin-top:4px;margin-left:4px;} "
+  "QToolButton:pressed{margin-top:5px;margin-left:5px;} "
+  "QLabel{color:black;font-weight:bold;padding:2px;} "
+  "QLineEdit{height:%1px;font-weight:bold;margin-top:2px;margin-left:2px;} ";
 
 MainWindow *mainWnd;
-TMapView *map;
 
-#if defined(Q_OS_WINCE) || defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_OS_ANDROID)
-bool MobileVersion=1;
-#else
-bool MobileVersion=0;
-#endif
+FlickCharm charm;
 
 IniSettingMap AppConfig;
 
@@ -58,14 +57,19 @@ QVector <QString> IniKeyStr;
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent), ui(new Ui::MainWindow),Completer(NULL),SettingWindow(NULL)
 {
- //TOOLBAR_STYLE="";
+#if defined(Q_OS_WINCE) || defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_OS_ANDROID)
+ MobileVersion=1;
+#else
+ MobileVersion=0;
+#endif
+
  //MobileVersion=1;
  mainWnd=this;
  IniGroupStr << "MapView"<<"Main"<<"Other";
  IniKeyStr << "StationCustomFont"<<"StationFont"<<"StationBack"<<"StationShadow"<<"StationBackColor"<<"StationShadowColor"<<
               "StationUpperCase"<<"StationWordWrap"<<"StationTransparency"<<
-                         "MapShowScrollbar"<<"WindowFullScreen"<<"MapShowTime"<<"MapShowBackground"<<"MapAntialiasing"<<"MapFastScrolling"<<
-                         "MapBackColor"<<"MapSimpleTransfers"<<"MapCleanCache"<<"MapLastFile"<<"UiScale";
+              "MapShowScrollbar"<<"WindowFullScreen"<<"MapShowTime"<<"MapShowBackground"<<"MapAntialiasing"<<"MapFastScrolling"<<
+              "MapBackColor"<<"MapSimpleTransfers"<<"MapCleanCache"<<"MapLastFile"<<"MapCaching"<<"UiScale";
 
 
  Config.appFont=qApp->font();
@@ -73,6 +77,7 @@ MainWindow::MainWindow(QWidget *parent) :
  appConfigFile=cachePath="";
 #ifdef Q_WS_MAEMO_5
  setAttribute(Qt::WA_Maemo5AutoOrientation);
+ setAttribute(Qt::WA_Maemo5StackedWindow);
  appPath="/home/user/MyDocs/Data/qMetro/";
  cachePath=appPath+".cache/";
  appConfigFile="/home/user/qMetro.ini";
@@ -92,32 +97,29 @@ MainWindow::MainWindow(QWidget *parent) :
  if(cachePath.isEmpty()) cachePath=appPath+"cache/";
  Config.appIconSize=ICONSIZE;
 
- if(QFile::exists(appConfigFile))
+ QSettings *ini=new QSettings(appConfigFile,QSettings::IniFormat);
+ QString key;
+ ini->beginGroup("Main");
+ Config.locale=ini->value("Locale","").toString();
+ Config.dockWidth=ini->value("DockWidth",0).toInt();
+ key="MapZoomFactor";
+ Config.mapZoomFactor=ini->value(key).toFloat();
+ Config.mapZoomFactorCheck=ini->contains(key);
+ key="MapPosition";
+ Config.mapPosition=ini->value(key).toPoint();
+ Config.mapPositionCheck=ini->contains(key);
+ key="Mobile";
+ if(ini->contains(key)) MobileVersion=ini->value(key).toInt();
+ key="Font";
+ if(ini->contains(key))
  {
-  QSettings *ini=new QSettings(appConfigFile,QSettings::IniFormat);
-  QString key;
-  ini->beginGroup("Main");
-  Config.locale=ini->value("Locale","").toString();
-  Config.dockWidth=ini->value("DockWidth",0).toInt();
-  key="MapZoomFactor";
-  Config.mapZoomFactor=ini->value(key).toFloat();
-  Config.mapZoomFactorCheck=ini->contains(key);
-  key="MapPosition";
-  Config.mapPosition=ini->value(key).toPoint();
-  Config.mapPositionCheck=ini->contains(key);
-
-  key="Mobile";
-  if(ini->contains(key)) MobileVersion=ini->value(key).toInt();
-  key="Font";
-  if(ini->contains(key))
-  {
-   Config.appFont.fromString(ini->value(key).toString());
-   qApp->setFont(Config.appFont);
-  }
+  Config.appFont.fromString(ini->value(key).toString());
+  qApp->setFont(Config.appFont);
  }
+ TOOLBAR_STYLE=ini->value("Styles",TOOLBAR_STYLE).toString();
 
  if(Config.locale.isEmpty()) Config.locale=QLocale::system().name().section("_",0,0);
- toggleLang(Config.locale);
+
 
  ui->setupUi(this);
 
@@ -130,11 +132,28 @@ MainWindow::MainWindow(QWidget *parent) :
 
  setWindowTitle(windowTitle()+VERSION);
 
+ toggleLang(Config.locale);
  map = new TMapView(appPath,cachePath);
  map->config.MobileVersion=MobileVersion;
+ map->config.locale=Config.locale;
  //if(MobileVersion) map->setStyleSheet(TOOLBAR_STYLE.arg(Config.appIconSize));
 
+ connect(map,SIGNAL(trackText(QString)),ui->textDescription,SLOT(setText(QString)));
+ if(!MobileVersion)
+   connect(map,SIGNAL(trackFinded(bool)),ui->mFind,SLOT(setChecked(bool)));
+ connect(map,SIGNAL(delayNames(QStringList)),this,SLOT(setDelayNames(QStringList)));
+
+ //map->config.enableCaching=1;
+ Config.mapKineticScrollCheck=0;
+ if(Config.mapKineticScrollCheck)
+ {
+  charm.activateOn(map);
+  connect(&charm,SIGNAL(started()),map,SLOT(mapStartDragging()));
+  connect(&charm,SIGNAL(finished()),map,SLOT(mapStopDragging()));
+ }
+
  loadSettings();
+
  ui->toolBar->setIconSize(QSize(Config.appIconSize,Config.appIconSize));
  QSplitter *splitter = new QSplitter;
  splitter->addWidget(ui->dock);
@@ -160,11 +179,6 @@ MainWindow::MainWindow(QWidget *parent) :
  //ui->menuHelp->addAction(ui->menuLanguage->menuAction());
 #endif
 
- connect(map,SIGNAL(trackText(QString)),ui->textDescription,SLOT(setText(QString)));
- if(!MobileVersion)
-  connect(map,SIGNAL(trackFinded(bool)),ui->mFind,SLOT(setChecked(bool)));
- connect(map,SIGNAL(delayNames(QStringList)),this,SLOT(setDelayNames(QStringList)));
-
  QLabel *label = new QLabel("");
  label->setMinimumWidth(0);
  label->setMinimumHeight(0);
@@ -194,8 +208,6 @@ MainWindow::MainWindow(QWidget *parent) :
   map->verticalScrollBar()->setValue(Config.mapPosition.y());
  }
 
- //foreach(QGraphicsItem *item,map->items()) item->update();
-
  if(AppConfig.value(igMain).value(ikWFullScreen).toInt())
       ui->mFullScreen->setChecked(1);
  else showMaximized();
@@ -211,12 +223,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
  connect(map->nodeAInfo, SIGNAL(triggered()),this, SLOT(nodeInformation()));
 
- if(map->nodeByID.count())
- {
-  Completer= new TCompleter(map->getNamesAndColors(),ui->eSearch);
-  connect(Completer, SIGNAL(doneCompletionByID(int)),map, SLOT(findTrackByID(int)));
-  connect(Completer, SIGNAL(doneSuggestByID(QList<int>)),map, SLOT(findedNodesToFront(QList<int>)));
- }
+ if(map->nodeByID.count()) Completer= new TCompleter(map,ui->eSearch);
 
  installEventFilter(this);
 
@@ -242,7 +249,6 @@ MainWindow::MainWindow(QWidget *parent) :
   connect(langAction, SIGNAL(triggered()),this, SLOT(toggleLang()));
  }
  if(MobileVersion) toggleLang(Config.locale);
-
 }
 
 MainWindow::~MainWindow()
@@ -278,6 +284,7 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *e)
   break;
  case QEvent::Resize:
   {
+   if(map->selectedNode.count()) map->selectedNodesToFront(1);
    //map->fitMap();
    return 1;
   }
@@ -373,9 +380,9 @@ void MainWindow::on_mOpen_triggered()
  if(Completer) delete Completer;
  map->loadMap(fileName);
  map->fitMap();
- map->update();
+ map->viewport()->update();
  ui->eSearch->setText("");
- Completer= new TCompleter(map->getNamesAndColors(),ui->eSearch);
+ Completer= new TCompleter(map,ui->eSearch);
 //qDebug() << "Load time: " << testTimer.elapsed();
 
 //#ifndef QT_NO_CURSOR
@@ -433,78 +440,86 @@ void MainWindow::setDelayNames(QStringList list)
 
 void MainWindow::on_mAbout_triggered()
 {
- QDialog About(this);
- QPushButton OK;
- QHBoxLayout HLayout;
- QVBoxLayout VLayout;
- QLabel Logo;
- QTextBrowser Info;
+ About *a=new About(this);
+ if(MobileVersion)
+      a->showMaximized();
+ else a->exec();
+// QDialog *About = new QDialog(this);
+// QPushButton OK(About);
+// QHBoxLayout HLayout;
+// QVBoxLayout VLayout;
+// QLabel Logo(About);
+// QTextBrowser Info(About);
 
-#ifdef Q_WS_MAEMO_5
- About.setAttribute(Qt::WA_Maemo5StackedWindow);
- About.setWindowFlags(Qt::Window);
- About.setAttribute(Qt::WA_Maemo5AutoOrientation);
-#endif
- //About.setWindowFlags(Qt::Tool);
- About.setWindowFlags(About.windowFlags() & (~Qt::WindowContextHelpButtonHint));
- About.setFixedWidth(500);
- About.setMinimumHeight(155);
- About.setFixedHeight(400);
- About.setWindowTitle(tr("About")+" qMetro");
- About.setLayout(&HLayout);
+//#ifdef Q_WS_MAEMO_5
+// About->setAttribute(Qt::WA_Maemo5StackedWindow);
+// About->setWindowFlags(Qt::Window);
+// About->setAttribute(Qt::WA_Maemo5AutoOrientation);
+//#else
+// FlickCharm fcharm;
+// fcharm.activateOn(&Info);
+//#endif
+// //About->setWindowFlags(Qt::Tool);
+// About->setWindowFlags(About->windowFlags() & (~Qt::WindowContextHelpButtonHint));
+// About->setFixedWidth(500);
+// About->setMinimumHeight(155);
+// About->setFixedHeight(400);
+// About->setWindowTitle(tr("About")+" qMetro");
+// About->setLayout(&HLayout);
 
- HLayout.addWidget(&Logo);
- //HLayout.setContentsMargins(5,5,0,0);
- HLayout.setAlignment(&Logo,Qt::AlignTop);
- Logo.setFixedWidth(64);
- Logo.setContentsMargins(0,5,0,0);
- Logo.setPixmap(QPixmap(":/qmetro.png"));
+// HLayout.addWidget(&Logo);
+// //HLayout.setContentsMargins(5,5,0,0);
+// HLayout.setAlignment(&Logo,Qt::AlignTop);
+// Logo.setFixedWidth(64);
+// Logo.setContentsMargins(0,5,0,0);
+// Logo.setPixmap(QPixmap(":/qmetro.png"));
 
- QString text=
- QString("<p><font size=6><b>qMetro</b></font> - %4.</p>"
-         "<p>%5 %1 &copy; 2011 <a href=\"mailto:guuleon@gmail.com\">Gusak Leonid</a>"
-         " - <a href=\"http://qmetro.sf.net\">qmetro.sf.net</a></p>"
-         "<p>%6: <a href=\"mailto:Boris@pMetro.su\">Muradov Boris</a>"
-         " - <a href=\"%10\">pMetro</a></p>"
-         "<p>%11</p>"
-         "<hr><b>%7:</b>"
-         "<p>%3</p>"
-         "<hr><b>%8:</b><ul type=\"circle\"><li>&nbsp;Qt %2<li>&nbsp;zlib + OSDaB</ul>"
-         "<hr>%9")
- .arg(VERSION).arg(QT_VERSION_STR).arg((map->params.mapAuthors.isEmpty() ? tr("Unknown author"):map->params.mapAuthors)) // 1
- .arg(tr("transit system map")).arg(tr("Version")).arg(tr("Author of map file format")) // 3
- .arg(tr("About current map file")).arg(tr("This program uses")) // 6
- .arg(tr("This program is distributed in the hope that it will be useful, "
-         "but WITHOUT ANY WARRANTY; without even the implied warranty of "
-         "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
-         "GNU General Public License for more details.")).arg(URL_MAPS).arg(tr("Author of translation: Gusak Leonid"));
+// QString hr=QString("<p><table height=2 width=100% bgcolor=%1><tr><td></table></p>")
+//            .arg(palette().color(QPalette::Mid).name());
+// QString text=
+// QString("<p><font size=6><b>qMetro</b></font> - %4.</p>"
+//         "<p>%5 %1 &copy; 2011 <a href=\"mailto:guuleon@gmail.com\">Gusak Leonid</a>"
+//         " - <a href=\"http://qmetro.sf.net\">qmetro.sf.net</a></p>"
+//         "<p>%6: <a href=\"mailto:Boris@pMetro.su\">Muradov Boris</a>"
+//         " - <a href=\"%10\">pMetro</a></p>"
+//         "<p>%11</p>"
+//         "<hr><b>%7:</b>"
+//         "<p>%3</p>"
+//         "<hr><b>%8:</b><ul type=\"circle\"><li>&nbsp;Qt %2<li>&nbsp;zlib + OSDaB</ul>"
+//         "<hr>%9")
+// .arg(VERSION).arg(QT_VERSION_STR).arg((map->params.mapAuthors.isEmpty() ? tr("Unknown author"):map->params.mapAuthors)) // 1
+// .arg(tr("transit system map")).arg(tr("Version")).arg(tr("Author of map file format")) // 3
+// .arg(tr("About current map file")).arg(tr("This program uses")) // 6
+// .arg(tr("This program is distributed in the hope that it will be useful, "
+//         "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+//         "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+//         "GNU General Public License for more details.")).arg(URL_MAPS).arg(tr("Author of translation: Gusak Leonid"));
 
- HLayout.addLayout(&VLayout);
- VLayout.addWidget(&Info);
- QPalette pal = Info.palette();
- pal.setBrush(QPalette::Base, Qt::transparent);
- pal.setColor(QPalette::Text,palette().color(QPalette::Text));
- Info.setPalette(pal);
- Info.setAttribute(Qt::WA_NoSystemBackground,1);
- Info.setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse);
- Info.setOpenExternalLinks(1);
- Info.setReadOnly(1);
- Info.setFrameShape(QFrame::NoFrame);
- //Info.setStyleSheet("#i{background:red;}"); //border: 2px solid green;}");
- Info.setText(text);
- //Info.setStyleSheet("hr{color:\""+palette().color(QPalette::Text).name()+"\"");
- if(!MobileVersion)
- {
-  VLayout.addWidget(&OK);
-  VLayout.setAlignment(&OK,Qt::AlignRight);
-  OK.setText(tr("OK"));
-  OK.setDefault(1);
-  OK.setMaximumWidth(75);
-  connect(&OK,SIGNAL(pressed()),&About,SLOT(accept()));
-  //About.exec();
- }//else
-  //About.show();
- About.exec();
+// text.replace("<hr>",hr);
+// HLayout.addLayout(&VLayout);
+// VLayout.addWidget(&Info);
+// QPalette pal = Info.palette();
+// pal.setBrush(QPalette::Base, Qt::transparent);
+// pal.setColor(QPalette::Text,palette().color(QPalette::Text));
+// Info.setPalette(pal);
+// Info.setAttribute(Qt::WA_NoSystemBackground,1);
+// Info.setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse);
+// Info.setOpenExternalLinks(1);
+// Info.setReadOnly(1);
+// Info.setFrameShape(QFrame::NoFrame);
+// Info.setText(text);
+// //Info.setStyleSheet("hr{color:palette(text)");
+
+// VLayout.addWidget(&OK);
+// VLayout.setAlignment(&OK,Qt::AlignRight);
+// OK.setText(tr("OK"));
+// OK.setDefault(1);
+// OK.setMaximumWidth(75);
+// connect(&OK,SIGNAL(pressed()),About,SLOT(accept()));
+
+// if(MobileVersion)
+//      About->showFullScreen();
+// else About->exec();
 }
 
 void MainWindow::on_mPreference_triggered()
@@ -514,7 +529,6 @@ void MainWindow::on_mPreference_triggered()
   SettingWindow = new Settings(this);
 
 #ifdef Q_WS_MAEMO_5
-  //SettingWindow= dynamic_cast<MainWindow*>(SettingWindow);
   SettingWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
   SettingWindow->setWindowFlags(Qt::Window);
   SettingWindow->setAttribute(Qt::WA_Maemo5AutoOrientation);
@@ -542,12 +556,16 @@ void MainWindow::toggleLang(QString locale)
 
  qApp->installTranslator(&appTranslator);
  Config.locale=locale;
- if(map) map->config.locale=locale;
 }
 
 void infoAddTab(QWidget *widget, const QString &Caption,const QString &Text)
 {
  QTextBrowser *TextEdit=new QTextBrowser();
+
+#ifndef Q_WS_MAEMO_5
+ FlickCharm *fcharm = new FlickCharm(TextEdit);
+ fcharm->activateOn(TextEdit);
+#endif
  TextEdit->setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse);
  TextEdit->setText(Text); 
  TextEdit->setReadOnly(1);
@@ -557,7 +575,10 @@ void infoAddTab(QWidget *widget, const QString &Caption,const QString &Text)
  TextEdit->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Ignored);
 
  if(widget->metaObject()->className()==QString("QTabWidget").toAscii())
+ {
   ((QTabWidget*)widget)->addTab(TextEdit,Caption);
+  if(!mainWnd->MobileVersion) TextEdit->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+ }
  else
  {
   ((QToolBox*)widget)->addItem(TextEdit,QIcon(":/img/bullet.png"),Caption);
@@ -608,6 +629,15 @@ void MainWindow::nodeInformation()
     MapScheme->config.enableDrawBackground=1;
     MapScheme->config.mapLastFile="";
     MapScheme->applyConfig();
+
+    if(MapScheme->config.enableCaching)
+    {
+     FlickCharm *fcharm=new FlickCharm(MapScheme);
+     fcharm->activateOn(MapScheme);
+     connect(fcharm,SIGNAL(started()),MapScheme,SLOT(mapStartDragging()));
+     connect(fcharm,SIGNAL(finished()),MapScheme,SLOT(mapStopDragging()));
+    }
+
     //MapScheme->setStyleSheet(TOOLBAR_STYLE.arg(Config.appIconSize));
 
     map->extractFiles(map->params.mapFile,FileName,map->params.mapPath);
@@ -615,8 +645,6 @@ void MainWindow::nodeInformation()
     MapScheme->state.mapLoaded=1;
     Tabs->addTab(MapScheme,key);
     TMobileUi *toolbars = new TMobileUi(this,MapScheme,1);
-
-    MapScheme->fitMap();
    }
   }else
    AllText+=QString("<h3>%1</h3><br>%2<br>").arg(key).arg(Info.Value);
@@ -649,7 +677,8 @@ void MainWindow::nodeInformation()
 void MainWindow::closeEvent(QCloseEvent * e)
 {
  if(!isVisible()) { e->accept(); return;} // FIX: double exec dont know why
-
+ map->state.mapLoaded=0;
+ setVisible(0);
  QSettings cfg(appConfigFile,QSettings::IniFormat);
  QString key;
  cfg.beginGroup("Main");
@@ -665,15 +694,21 @@ void MainWindow::closeEvent(QCloseEvent * e)
  if(ui->mSavePosition->isChecked())
       cfg.setValue(key,QPoint(map->horizontalScrollBar()->value(),map->verticalScrollBar()->value()));
  else cfg.remove(key);
+ if(MobileVersion) cfg.setValue("Styles",TOOLBAR_STYLE);
 
  if(AppConfig.value(igOther).value(ikMCleanCache).toInt()) removeDir(cachePath);
+
+ if(map->config.enableCaching && !QFile::exists(map->params.mapPath+".cache"))
+  map->CachedMap->save(map->params.mapPath+".cache","PNG");
  map->clearMap();
- setVisible(0);
+
+ //setVisible(0);
  e->accept();
 }
 
 void applySettings(const IniSettingMap &settings)
 {
+ TMapView *map=mainWnd->map;
  if(!settings.count()) return;
 
  QFont nodeFont;
@@ -714,6 +749,7 @@ void applySettings(const IniSettingMap &settings)
    case ikMFastScrolling: map->config.enableLowqDrag=value.toInt(); break;
    case ikMSimpleTransfers: map->config.enableSimpleTransfer=value.toInt(); break;
    case ikMLastFile: map->config.mapLastFile=value; break;
+   case ikMCaching: map->config.enableCaching=value.toInt(); break;
    case ikWUiScale: mainWnd->setScaleForUi((qreal)value.toFloat()); break;
    default: break;
    }
@@ -774,6 +810,7 @@ void saveSettings(const IniSettingMap &settings)
 
 void loadSettings()
 {
+ TMapView *map=mainWnd->map;
  map->defaultConfig();
 
  QSettings cfg(appConfigFile,QSettings::IniFormat);
@@ -841,10 +878,9 @@ qint64 sizeOfDir(const QString &DirName)
 
 void MainWindow::on_mAddMap_triggered()
 {
- QString URL,MapPath=appPath+"Map/";
- URL="http://translate.google.com/translate?sl=ru&tl=%1&u=%2";
+ QString MapPath=appPath+"Map/";
  if(Config.locale!="ru")
-      QDesktopServices::openUrl(QUrl(URL.arg(Config.locale).arg(URL_MAPS)));
+      QDesktopServices::openUrl(QUrl(URL_TRANSLATE.arg(Config.locale).arg(URL_MAPS)));
  else QDesktopServices::openUrl(QUrl(URL_MAPS));
  MapPath=QDir::toNativeSeparators(MapPath);
  QMessageBox::information(this,tr("Add maps"),tr("1. Wait until loaded site...\n2. Select map\n3. Save file map here:")+"\n     "+MapPath);
