@@ -12,7 +12,7 @@ enum IniGroup{igMapView,igMain,igOther};
 enum IniKey{ikStationCustomFont,ikStationFont,ikStationBack,ikStationShadow,ikSBackColor,ikSShadowColor,
             ikSUpperCase,ikSWordWrap,ikSTransparency,
             ikMShowScrollbar,ikWFullScreen,ikMShowTime,ikMShowBackground,ikMAntialiasing,ikMFastScrolling,
-            ikMBackColor,ikMSimpleTransfers,ikMCleanCache,ikMLastFile,ikWUiScale};
+            ikMBackColor,ikMSimpleTransfers,ikMCleanCache,ikMLastFile,ikMCaching,ikWUiScale};
 
 typedef QMap<IniKey,QString> IniKeyMap;
 typedef QMap<IniGroup,IniKeyMap> IniSettingMap;
@@ -38,6 +38,7 @@ public:
 
     //void showEvent(QShowEvent * event);
 
+    TMapView *map;
     Settings *SettingWindow;
 
     struct TConfig
@@ -48,6 +49,7 @@ public:
      QPoint mapPosition;
      bool mapZoomFactorCheck;
      bool mapPositionCheck;
+     bool mapKineticScrollCheck;
 
      QFont appFont;
      qreal appUiScale;
@@ -57,6 +59,8 @@ public:
      QSize settingWindow;
     };
     TConfig Config;
+
+    bool MobileVersion;
     TMobileUi *mUi;
 
 protected:
