@@ -60,7 +60,7 @@ void TMapElement::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWi
 
    if(map->selectedNode.count()) // nodes
    {
-    int width=map->params.nodeWidth*1.4;
+    int width=map->params.nodeWidth*1.3;
     p->setPen(Qt::NoPen);
     p->setBrush(Qt::black);
     foreach(TMapNode *node,map->selectedNode)
@@ -82,7 +82,8 @@ void TMapElement::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWi
       tPath.addPath(edge->path);
      }
 
-    p->setPen(QPen(Qt::black,map->params.routeWidth*1.8,Qt::SolidLine,Qt::RoundCap,Qt::RoundJoin));
+    // black border for transfers
+    p->setPen(QPen(Qt::black,map->params.routeWidth*1.5,Qt::SolidLine,Qt::FlatCap,Qt::RoundJoin));
     p->drawPath(tPath);
     foreach(TMapEdge *edge, map->selectedEdge)
     {
@@ -93,13 +94,14 @@ void TMapElement::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWi
      }
      else continue;
 
-     p->setPen(QPen(Qt::black,width*1.5,Qt::SolidLine,Qt::RoundCap,Qt::RoundJoin));
+     // black border for lines
+     p->setPen(QPen(Qt::black,width*1.3,Qt::SolidLine,Qt::FlatCap,Qt::RoundJoin));
      p->drawPath(edge->path);
-     p->setPen(QPen(color,width,Qt::SolidLine,Qt::RoundCap,Qt::RoundJoin));
+     p->setPen(QPen(color,width,Qt::SolidLine,Qt::FlatCap,Qt::RoundJoin));
      p->drawPath(edge->path);
      //qDebug() << edge->node[0]->ID << edge->node[1]->ID;
     }
-    p->setPen(QPen(Qt::white,map->params.routeWidth*1.2,Qt::SolidLine,Qt::RoundCap,Qt::RoundJoin));
+    p->setPen(QPen(map->params.mapColorBack.lighter(150),map->params.routeWidth*1.2,Qt::SolidLine,Qt::FlatCap,Qt::MiterJoin));
     p->drawPath(tPath);
    }
 
