@@ -39,7 +39,6 @@ TMapNode::TMapNode(TMapView *nodeMap,TMapRoute *nodeRoute, QString nodeName, int
 }
 void TMapNode::init()
 {
- QPainter p; // fake
  int sWidth=Map->params.nodeWidth;
  QRectF r;
  bool leftAlign=0;
@@ -67,6 +66,8 @@ void TMapNode::init()
   }
   Align+=Qt::AlignLeft;
 
+  QPixmap pix(NRect90.size());
+  QPainter p(&pix); // fake
   QMatrix matrix;
   QPainterPath pRect;
 
@@ -122,6 +123,15 @@ void TMapNode::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidge
 {
  if(!Map->state.mapLoaded) return;
 
+ if(Map->config.enableCaching && Map->state.mapCached)
+ {
+  bool sign=1;
+  foreach(TMapNode *node,Map->selectedNode)
+   if(node->ID==ID) {sign=0; break;}
+
+  if(Map->nodeBeginID!=ID && Map->nodeEndID!=ID && sign) return;
+ }
+
  if(HasTransfer) p->setPen(QPen(Qt::white,1));
  else            p->setPen(QPen(Qt::yellow,1));
 
@@ -144,15 +154,18 @@ void TMapNode::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidge
  }
 
  p->drawPath(PathNode);
- if(Map->config.enableWriteTime && Map->nodeBegin && TypeNode!=ntConstruct && Map->mapDistance.count())
+ if(Map->config.enableWriteTime && Map->nodeBegin && TypeNode!=ntConstruct && Map->mapDistance.count()
+    && (!Map->config.enableCaching || (Map->config.enableCaching && Map->state.mapCached)) )
  {
-  QFont f=Map->params.nodeFont;
-  p->setPen(Qt::white);
-  f.setPointSize(Map->params.nodeWidth);
-  p->setFont(f);
   int dist=Map->mapDistance[ID];
   if(dist<INFINIT)
-    p->drawText(EllipseRect,Qt::AlignCenter,QString::number(int(dist/60)));                                          //QString::number(ID));
+  {
+   QFont f=Map->params.nodeFont;
+   p->setPen(Qt::white);
+   f.setPointSize(Map->params.nodeWidth);
+   p->setFont(f);
+   p->drawText(EllipseRect,Qt::AlignCenter,QString::number(int(dist/60)));                                          //QString::number(ID));
+  }
  }
  //else { p->setFont(QFont("Tahoma",5)); p->drawText(EllipseRect,Qt::AlignCenter,QString::number(int(ID)));}
 
@@ -182,7 +195,7 @@ void TMapNode::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidge
   {
    p->setBackgroundMode(Qt::TransparentMode);
    p->setPen(Qt::white);
-   p->drawText(TextRect.adjusted(-0.4,-0.4,-0.4,-0.4),Align,DisplayName);
+   p->drawText(TextRect.adjusted(-0.2,-0.2,-0.2,-0.2),Align,DisplayName);
 
    p->setPen(Route->color.dark());
    p->drawText(TextRect.adjusted(0.3,0.3,0.3,0.3),Align,DisplayName);
@@ -192,7 +205,7 @@ void TMapNode::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidge
   {
    p->setBackgroundMode((Map->config.enableStationBackColor ? Qt::OpaqueMode:Qt::TransparentMode));
    p->setPen(Map->params.nodeColorShadow);
-   p->drawText(TextRect.adjusted(0.3,0.3,0.3,0.3),Align,DisplayName);
+   p->drawText(TextRect.adjusted(0.6,0.6,0.6,0.6),Align,DisplayName);
    p->setBackgroundMode(Qt::TransparentMode);
   }
 
