@@ -1,4 +1,8 @@
-//#include <QDebug>
+#if OPENGL_ENABLE
+#include <QtOpenGL>
+#endif
+
+#include <QDebug>
 #include <QSettings>
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
@@ -20,11 +24,6 @@
 #include <QPair>
 #include <QScrollBar>
 
-#if defined(Q_WS_MAEMO_5) //defined(Q_OS_WIN32) //! Q_OS_WINCE Q_OS_SYMBIAN)
- #include <QtOpenGL/QGLWidget>
- #include <QtOpenGL/QGLFormat>
-#endif
-
 #include "../zip/unzip.h"
 #include "../ini/inisettings.h"
 
@@ -45,7 +44,7 @@ const QPainter::RenderHints NonAntialiasing=QPainter::NonCosmeticDefaultPen;
 QString ru="ru";
 
 TMapView::TMapView(QString AppPath, QString CachePath) :
-  nodeBegin(NULL),nodeEnd(NULL),mapWidth(0),mapHeight(0),
+  nodeBegin(NULL),nodeEnd(NULL),mapWidth(0),mapHeight(0),CachedMap(NULL),
   nodeClick(NULL),mapFade(NULL),nodeBeginID(-1),nodeEndID(-1)
 {
  hide();
@@ -53,10 +52,10 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
  setAttribute(Qt::WA_NoSystemBackground);
  setAttribute(Qt::WA_PaintOnScreen);
 
-#if 0 //defined(Q_WS_MAEMO_5) //defined(Q_OS_WIN32) //!(defined Q_OS_WINCE || defined Q_OS_SYMBIAN)
+#if OPENGL_ENABLE //defined(Q_WS_MAEMO_5) //defined(Q_OS_WIN32) //!(defined Q_OS_WINCE || defined Q_OS_SYMBIAN)
  if(QGLFormat::hasOpenGL())
  {
-  QGLWidget *gl=new QGLWidget(QGLFormat(QGL::SampleBuffers),this);
+  QGLWidget *gl=new QGLWidget(QGLFormat(QGL::SampleBuffers));
   //gl->context()->format().setDoubleBuffer(1);
   setViewport(gl); //QGLWidget(QGLFormat::defaultFormat(), this)
  }
@@ -73,8 +72,8 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
 
  scene = new QGraphicsScene(this);
  //scene->setItemIndexMethod - setup later at load
- setOptimizationFlag(QGraphicsView::DontAdjustForAntialiasing,1);
- setOptimizationFlag(QGraphicsView::DontSavePainterState,1);
+ //setOptimizationFlag(QGraphicsView::DontAdjustForAntialiasing);
+ setOptimizationFlag(QGraphicsView::DontSavePainterState);
  scene->setSceneRect(0, 0, width(), height());
  setScene(scene);
  setFrameShape(NoFrame);
@@ -82,18 +81,17 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
  //setCacheMode(QGraphicsView::CacheBackground);
  //setViewportUpdateMode(QGraphicsView::SmartViewportUpdate);
  //setViewportUpdateMode(QGraphicsView::MinimalViewportUpdate);
- setViewportUpdateMode(BoundingRectViewportUpdate);
+ //setViewportUpdateMode(BoundingRectViewportUpdate);
  //setViewportUpdateMode(FullViewportUpdate);
  if(config.MobileVersion) setInteractive(0);
  setDragMode(QGraphicsView::ScrollHandDrag);
  setTransformationAnchor(AnchorUnderMouse);
  setResizeAnchor(AnchorViewCenter);
  
+ state.mapCached=0;
  params.delayIndex=params.delayMetro=0;
  params.appPath=AppPath;
  params.mapCachePath=CachePath;
-
- 
  params.appName=qApp->applicationName();
  codePage = QTextCodec::codecForName("windows-1251");
  
@@ -103,21 +101,46 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
  
  nodeAInfo = new QAction(QIcon(":/img/dialog-information.png"),tr("Information"),this);
  nodePopup = new QMenu();
+ nodePopup->addAction(nodeAInfo);
+ nodePopup->addSeparator();
  nodePopup->addAction(tr("Start"));
  nodePopup->addAction(tr("Finish"));
- nodePopup->addSeparator();
- nodePopup->addAction(nodeAInfo);
- connect(nodePopup->actions().at(0),SIGNAL(triggered()),this,SLOT(setNodeBegin()));
- connect(nodePopup->actions().at(1),SIGNAL(triggered()),this,SLOT(setNodeEnd()));
+ connect(nodePopup->actions().at(2),SIGNAL(triggered()),this,SLOT(setNodeBegin()));
+ connect(nodePopup->actions().at(3),SIGNAL(triggered()),this,SLOT(setNodeEnd()));
  
  QPalette palette;
  palette.setColor(backgroundRole(), Qt::white);
  setPalette(palette);
 
-// params.horizontalScroll=horizontalScrollBar();
-// params.verticalScroll=verticalScrollBar();
-// connect(params.horizontalScroll,SIGNAL(valueChanged(int)),this,SLOT(valueChangedScroll(int)));
-// connect(params.verticalScroll,SIGNAL(valueChanged(int)),this,SLOT(valueChangedScroll(int)));
+ connect(horizontalScrollBar(),SIGNAL(sliderPressed()),this,SLOT(mapStartDragging()));
+ connect(verticalScrollBar(),SIGNAL(sliderPressed()),this,SLOT(mapStartDragging()));
+ connect(horizontalScrollBar(),SIGNAL(sliderReleased()),this,SLOT(mapStopDragging()));
+ connect(verticalScrollBar(),SIGNAL(sliderReleased()),this,SLOT(mapStopDragging()));
+}
+
+void TMapView::mapStartDragging()
+{
+ if(!state.mapDragging )
+ {
+  if(config.enableLowqDrag && config.enableAntialiasing)
+  {
+   setRenderHints(NonAntialiasing);
+  }
+  state.mapDragging=1;
+ }
+}
+
+void TMapView::mapStopDragging()
+{
+ if(state.mapDragging )
+ {
+  if(config.enableLowqDrag)
+  {
+   if(config.enableAntialiasing) setRenderHints(Antialiasing);
+   //else
+  }
+  state.mapDragging=0;
+ }
 }
 
 TMapView::~TMapView()
@@ -125,14 +148,6 @@ TMapView::~TMapView()
  clearMap();
 }
 
-//void TMapView::valueChangedScroll(int value)
-//{
-// int x=params.horizontalScroll->value();
-// int y=params.verticalScroll->value();
-// QPointF pos=mapToScene(QPoint(x,y));
-// params.scrollPos=pos.toPoint();
-//}
-
 void TMapView::keyPressEvent(QKeyEvent *event)
 {
     switch (event->key())
@@ -160,13 +175,63 @@ void TMapView::wheelEvent(QWheelEvent *event)
 void TMapView::drawBackground(QPainter *painter, const QRectF &rect)
 {
  Q_UNUSED(rect);
- QRectF sceneRect = this->sceneRect();
- painter->fillRect(sceneRect,params.mapColorBack);
- if(state.mapLoaded)
- {
-  //testTimer.start();
-  if(config.enableDrawBackground) drawPaintCmd(painter,paintBkg);
-  drawPaintCmd(painter,paintMap);
+// testTimer.start();
+
+  if(state.mapLoaded)
+  {
+   if(config.enableCaching)
+   {
+    if(state.mapCached)
+     painter->drawPixmap(0,0,*CachedMap);
+    else
+    {
+     if(!mapWidth || !mapHeight) drawPaintCmd(painter,paintBkg);
+     QRect rect(0,0,mapWidth,mapHeight);
+     if(CachedMap) delete CachedMap;
+     CachedMap = new QPixmap(mapWidth,mapHeight);
+     CachedMap->fill(params.mapColorBack);
+     if(QFile::exists(params.mapPath+".cache") && nodeByID.count())
+     {
+      CachedMap->load(params.mapPath+".cache","PNG");
+      state.mapCached=1;
+      painter->drawPixmap(0,0,*CachedMap);
+      return;
+     }
+     QPainter p(CachedMap);
+     //p.scale(params.mapZoomFactor*1.2,params.mapZoomFactor*1.2);
+     p.setRenderHints(Antialiasing);
+     if(config.enableDrawBackground) drawPaintCmd(&p,paintBkg);
+     if(nodeByID.count())
+     {
+      bool sv=0;
+      int tmpBegin=nodeBeginID, tmpEnd=nodeEndID;
+      drawPaintCmd(&p,paintMap);
+      if(mapFade) sv=mapFade->isVisible();
+      if(sv) mapFade->setVisible(0);
+      nodeBeginID=nodeEndID=-1;
+      foreach(TMapNode *node,nodeByID) node->update();
+      scene->render(&p,rect,rect);
+      nodeBeginID=tmpBegin; nodeEndID=tmpEnd;
+      if(sv) mapFade->setVisible(1);
+     }
+//     if(!QFile::exists(params.mapPath+".cache"))
+//      CachedMap->save(params.mapPath+".cache","PNG");
+     state.mapCached=1;
+     painter->drawPixmap(0,0,*CachedMap);
+    }
+   }else
+   {
+    if(!mapWidth || !mapHeight) drawPaintCmd(painter,paintBkg);
+    painter->fillRect(sceneRect(),params.mapColorBack);
+    if(config.enableDrawBackground) drawPaintCmd(painter,paintBkg);
+    drawPaintCmd(painter,paintMap);
+   }
+
+
+
+
+
+
   //qDebug() << testTimer.elapsed();
 
 
@@ -200,6 +265,7 @@ void TMapView::scaleMap(qreal scaleFactor)
  params.mapZoomFactor = matrix().scale(scaleFactor, scaleFactor).m11(); //mapRect(QRectF(0, 0, 1, 1)).width();
  if (params.mapZoomFactor < qreal(0.1) || params.mapZoomFactor > qreal(20)) return;
  scale(scaleFactor, scaleFactor);
+ //state.mapCached=0;
  //if(config.enableAntialiasing) setRenderHints(Antialiasing);
 }
 
@@ -268,7 +334,7 @@ void TMapView::loadMap(QString fileName)
   params.mapDelayNames=QString("%1,%2,%3").arg(day).arg(night).arg(none);
  else params.mapDelayNames+=","+none;
 
- //qDebug() << params.delayNames << params.delayNames.split(",").count();
+ //qDebug() << params.mapDelayNames << params.mapDelayNames.split(",").count();
  QStringList delayList;
  if(config.enableTranslit)
  {
@@ -281,10 +347,11 @@ void TMapView::loadMap(QString fileName)
    if(str=="den'") delayList.replace(i,day);
    else if(str=="noch'") delayList.replace(i,night);
    else if(str=="chas-pik") delayList.replace(i,rush);
+   else if(str=="ne uchityvat'") delayList.replace(i,none);
   }
  }
  else delayList=params.mapDelayNames.split(",");
-
+ //qDebug() << delayList;
  emit delayNames(delayList);
 
  INISettings ini(params.mapPath+"Metro.map",codePage);
@@ -294,6 +361,8 @@ void TMapView::loadMap(QString fileName)
  params.nodeWidth=ini.value("StationDiameter","16").toInt()/2;
  params.nodeConstructWidth=params.nodeWidth*qreal(0.7);
  params.routeWidth=ini.value("LinesWidth","9").toInt();
+ if(params.routeWidth/params.nodeWidth>1.8) // some freak map :)
+  params.routeWidth=params.nodeWidth;
  params.nodeUpperCase=ini.value("UpperCase","1",vtBoolean).toInt();
  params.nodeWordWrap=ini.value("WordWrap","1",vtBoolean).toInt();
  params.mapIsVector=ini.value("IsVector","1",vtBoolean).toInt();
@@ -357,13 +426,14 @@ void TMapView::loadMap(QString fileName)
 
 void TMapView::exportMap(QString fileName,QString ext)
 {
- QImage image(scene->width(), scene->height(), QImage::Format_ARGB32_Premultiplied);
+ QRectF rect(0,0,mapWidth, mapHeight);
+ QImage image(mapWidth, mapHeight, QImage::Format_ARGB32_Premultiplied);
  image.fill(NULL);
  QPainter painter(&image);
- painter.setRenderHints(Antialiasing,1);
+ painter.setRenderHints(Antialiasing);
  drawBackground(&painter,scene->sceneRect());
- scene->render(&painter);
- image.save(fileName,ext.toAscii(),100);
+ scene->render(&painter,rect,rect);
+ image.save(fileName,ext.toAscii());
 }
 
 bool TMapView::extractFiles(QString zipFile, QString extractFiles, QString extractDir)
@@ -482,7 +552,7 @@ void TMapView::addPaintCmd(const QString &eParam,DrawType eType,QList<TPaintCmd>
    QString imageFile,ext=param.at(0).right(4).toUpper();
    imageFile=params.mapPath+param.at(0);
    if(!QFile::exists(imageFile)) extractFiles(params.mapFile,param.at(0),params.mapPath);
-   if(param.size()>1)
+   if(param.count()>1)
    {
     x=param.at(1).toInt();
     y=param.at(2).toInt();
@@ -500,7 +570,7 @@ void TMapView::addPaintCmd(const QString &eParam,DrawType eType,QList<TPaintCmd>
     cmd.type=dtImage;
     paintCmd << cmd;
    }
-   if(param.size()>1)
+   if(param.count()>1)
    {
     cmd.type=dtTranslate;
     cmd.nums.clear();
@@ -717,6 +787,8 @@ void TMapView::clearMap()
    if(paintBkg.at(i).image!=NULL) delete paintBkg.at(i).image;
  paintBkg.clear();
  paintMap.clear();
+ state.mapCached=0;
+
  for(int a=0;a<edgeCache.count();a++) delete edgeCache.at(a);
  edgeCache.clear();
 
@@ -754,7 +826,6 @@ void TMapView::clearMap()
  }
  layer.clear();
 
-
 }
 
 void TMapView::loadMapLayers(QString LayerFilesTRP)
@@ -1206,7 +1277,7 @@ void TMapView::addLayerToPaintCmd(TMapLayer *mapLayer,QList<TPaintCmd> &paintCmd
 
   tCmd = TPaintCmd();
 
-  tCmd.pen=QPen(Qt::white,tWidth*qreal(1.2),Qt::SolidLine,Qt::SquareCap,Qt::MiterJoin);
+  tCmd.pen=QPen(params.mapColorBack.lighter(150),tWidth*1.2,Qt::SolidLine,Qt::SquareCap,Qt::MiterJoin);
   tCmd.type=dtPenColor;
   paintCmd << tCmd;
 
@@ -1220,11 +1291,12 @@ void TMapView::addLayerToPaintCmd(TMapLayer *mapLayer,QList<TPaintCmd> &paintCmd
 void TMapView::mouseMoveEvent(QMouseEvent *event)
 {
  QGraphicsView::mouseMoveEvent(event);
- if(event->buttons()==Qt::LeftButton && renderHints()!=NonAntialiasing)
+ if(event->buttons()==Qt::LeftButton && !state.mapDragging )
  {
-  if(config.enableAntialiasing && config.enableLowqDrag)
+  if(config.enableLowqDrag && config.enableAntialiasing)
   {
    //params.nodeFont.setStyleStrategy(QFont::NoAntialias);
+   //params.nodeFont.setStyleStrategy(QFont::PreferDefault);
    setRenderHints(NonAntialiasing);
   }
   state.mapDragging=1;
@@ -1249,42 +1321,34 @@ void TMapView::mousePressEvent (QMouseEvent *event)
 
  nodeClickPos=event->pos();
  if(event->button()==Qt::MidButton) fitMap();
- if(event->button()==Qt::LeftButton) TimerPopup.start();
+ if(event->button()==Qt::LeftButton || event->button()==Qt::RightButton)
+ {
+  bool sv=0;
+  if(mapFade) sv=mapFade->isVisible();
+  if(sv) mapFade->setVisible(0);
+  nodeClick=(TMapNode*)itemAt(nodeClickPos);
+  if(sv) mapFade->setVisible(1);
+ }
+ if(event->button()==Qt::LeftButton)
+ {
+  if(nodeClick && nodeClick->type()==elNode) TimerPopup.start();
+ }
 }
 
 void TMapView::popupByTimer()
 {
- bool sv=0;
- if(mapFade) sv=mapFade->isVisible();
- if(sv) mapFade->setVisible(0);
- nodeClick=(TMapNode*)itemAt(nodeClickPos);
- if(sv) mapFade->setVisible(1);
-
- if(!nodeClick  || nodeClick->type()!=elNode){ return; }
-
  setDragMode(QGraphicsView::NoDrag);
  nodePopup->popup(mapToGlobal(nodeClickPos));
+ if(config.enableLowqDrag && config.enableAntialiasing)
+  setRenderHints(Antialiasing);
  setDragMode(QGraphicsView::ScrollHandDrag);
 }
 
 void TMapView::mouseReleaseEvent(QMouseEvent *event)
 {
-
  QGraphicsView::mouseReleaseEvent(event);
 
- bool sv=0;
- if(mapFade) sv=mapFade->isVisible();
- if(sv) mapFade->setVisible(0);
- emit nodeClicked(0);
- QGraphicsItem *item=itemAt(event->pos());
  emit nodeClicked(1);
- if(sv) mapFade->setVisible(1);
- if(event->button()==Qt::RightButton)
- {
-  if(item==NULL || item->type()!=elNode) return;
-  nodeClick=(TMapNode*)item;
-  nodePopup->popup(mapToGlobal(event->pos()));
- }
 
  if(event->button()==Qt::LeftButton)
  {
@@ -1293,48 +1357,58 @@ void TMapView::mouseReleaseEvent(QMouseEvent *event)
   {
    if(config.enableLowqDrag)
    {
-    //params.nodeFont.setStyleStrategy(QFont::PreferAntialias);
-    setRenderHints((config.enableAntialiasing ? Antialiasing:NonAntialiasing)); // Antialiasing after drag
-    //foreach(TMapNode *node,nodeByID) node->update(); // fix paint nodes
+    if(config.enableAntialiasing)
+    {
+     setRenderHints(Antialiasing);
+     //params.nodeFont.setStyleStrategy(QFont::PreferAntialias);
+    }
+//    else
+//     params.nodeFont.setStyleStrategy(QFont::PreferDefault);
    }
    state.mapDragging=0;
   }
+ }
 
-  if(QLineF(nodeClickPos,event->pos()).length()>8) return;
-  if(item==NULL || item->type()!=elNode)
+ if(QLineF(nodeClickPos,event->pos()).length()>8) return;
+
+ if((event->button()==Qt::LeftButton || event->button()==Qt::RightButton)
+    && (!nodeClick || nodeClick->type()!=elNode))
+ {
+  if(!config.MobileVersion)
   {
-   if(!config.MobileVersion)
-   {
-    clearTrack();
-    if(nodeClick) nodeClick->update();
-   }
-   return;
+   clearTrack();
+   if(nodeClick) nodeClick->update();
   }
-  TMapNode *node=(TMapNode*)item;
-  if(node->TypeNode==TMapNode::ntConstruct) return;
+  return;
+ }
 
+ if(event->button()==Qt::RightButton)
+ {
+  nodePopup->popup(mapToGlobal(event->pos()));
+ }
+
+ if(event->button()==Qt::LeftButton)
+ {
+  if(nodeClick->TypeNode==TMapNode::ntConstruct) return;
 
  //testTimer.start();
-  findTrack(node);
+  findTrack(nodeClick);
  //qDebug() << testTimer.elapsed();
-
-  //if(nodeClick) nodeClick->update();
-  //node->update();
-  nodeClick=node;
  }
+
 }
 
 void TMapView::selectedNodesToFront(bool enable)
 {
  if(!selectedNode.count()) return;
 
- QRectF rect=selectedNode.at(0)->Rect;
- int z=(enable ? 2:-1),nWidth=rect.width();
+ QRectF rect=selectedNode.at(0)->mapToScene(selectedNode.at(0)->boundingRect()).boundingRect();;
+ int z=(enable ? 2:-1),nPadding=params.nodeWidth*2;
  foreach(TMapNode *node, selectedNode)
  {
   if(enable)
   {
-   QRectF nRect=node->Rect;
+   QRectF nRect=node->mapToScene(node->boundingRect()).boundingRect();
    if(nRect.left()<rect.left())rect.setLeft(nRect.left());
    if(nRect.top()<rect.top())  rect.setTop(nRect.top());
    if(nRect.right()>rect.right())  rect.setRight(nRect.right());
@@ -1342,14 +1416,14 @@ void TMapView::selectedNodesToFront(bool enable)
   }
   node->setZValue(z);
  }
+
  if(!enable) selectedNode.clear();
  mapFade->setVisible(enable);
  if(enable)
  {
-  if((rect.width()+rect.height())/nWidth>3)
-       nWidth/=3;
-  else nWidth*=2;
-  rect.adjust(-nWidth,-nWidth,nWidth,nWidth);
+  int wh=qMin(rect.width(),rect.height());
+  nPadding*=(wh/nPadding<qreal(4.0) ? 10:3);
+  rect.adjust(-nPadding,-nPadding,nPadding,nPadding);
   fitInView(rect,Qt::KeepAspectRatio);
  }
 }
@@ -1427,16 +1501,14 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end)
  for(int i=0;i<id.count()-1;i++)
   selectedEdge << mapGraph[id.at(i)][id.at(i+1)];
 
- QString info,br,small,font,line,text;
+ QString br="<br>";
+ QString line=" "+tr("line")+")";
+ QString font="<table width=\"100%\" style=\"COLOR:white;BACKGROUND-COLOR:%1\"><tr><td align=\"center\"><b>&nbsp;%2</b></tr></table>";
+ QString smallTag="<small>%1</small>";
 
- br="<br>";
- line=" "+tr("line")+")";
- font="<table width=\"100%\" style=\"COLOR:white;BACKGROUND-COLOR:%1\"><tr><td align=\"center\"><b>&nbsp;%2</b></tr></table>";
- small="<small>%1</small>";
-
- text=small.arg("%4")+
+ QString text=smallTag.arg("%4")+
       font.arg("%5").arg("%6")+
-      "<center>"+small.arg("%7")+"</center><hr>";
+      "<center>"+smallTag.arg("%7")+"</center><hr>";
 
  text=text.arg(tr("Begin station:")) // 4
           .arg(nodeBegin->Route->color.name()) //5
@@ -1450,17 +1522,17 @@ void TMapView::findTrack(TMapNode *begin,TMapNode *end)
   if(edge->type==TMapEdge::etTransfer)
   {
    countTransfer++;
-   text+=small.arg(tr("Go to station:"))+
+   text+=smallTag.arg(tr("Go to station:"))+
          font.arg(edge->node[1]->Route->color.name()).arg(edge->node[1]->DisplayName)+
-         small.arg(tr("Transfer to station:"))+
+         smallTag.arg(tr("Transfer to station:"))+
          font.arg(edge->node[0]->Route->color.name()).arg(edge->node[0]->DisplayName)+"<hr>";
   }
  }
 
- text+=small.arg(tr("Final station:"))+
-       font.arg(nodeEnd->Route->color.name()).arg(nodeEnd->DisplayName)+"<center>"+small.arg("("+nodeEnd->Route->DisplayName+line)+"</center>";
-
+ text+=smallTag.arg(tr("Final station:"))+
+       font.arg(nodeEnd->Route->color.name()).arg(nodeEnd->DisplayName)+"<center>"+smallTag.arg("("+nodeEnd->Route->DisplayName+line)+"</center>";
 
+ QString info;
  if(config.MobileVersion)
  {
   info="%1 %2 %3"+br+
@@ -1500,7 +1572,7 @@ void TMapView::clearTrack()
  selectedNodesToFront(0);
  selectedNode.clear();
  selectedEdge.clear();
- if(nodeByID.count()) foreach(TMapNode *node,nodeByID) node->update();
+ //if(nodeByID.count()) foreach(TMapNode *node,nodeByID) node->update();
  emit trackText("");
  if(config.MobileVersion) emit trackFinded(0);
 }
@@ -1571,6 +1643,7 @@ void TMapView::defaultConfig()
  config.enableWriteTime=1;
  config.enableSimpleNode=0;
  config.enableDrawBackground=1;
+ config.enableCaching=config.MobileVersion;
  config.valueTransparency=60;
  params.mapColorBack=Qt::white;
 }
@@ -1591,11 +1664,23 @@ void TMapView::applyConfig()
  if(nodeByID.isEmpty() && !config.mapLastFile.isEmpty()) loadMap(config.mapLastFile);
  config.mapLastFile="";
 
- if(config.enableAntialiasing)
-      params.nodeFont.setStyleStrategy(QFont::PreferAntialias);
- else params.nodeFont.setStyleStrategy(QFont::PreferDefault);
+  if(config.enableAntialiasing)
+       params.nodeFont.setStyleStrategy(QFont::PreferAntialias);
+  else params.nodeFont.setStyleStrategy(QFont::PreferDefault);
+ //params.nodeFont.setStyleStrategy(QFont::ForceOutline);
+
+ if(config.enableCaching)
+      setViewportUpdateMode(FullViewportUpdate);
+ else setViewportUpdateMode(QGraphicsView::SmartViewportUpdate);
 
  if(mapFade) mapFade->FadeOpacity=config.valueTransparency/qreal(100);
+
+ if(config.enableCaching && state.mapCached)
+ {
+  QFile::remove(params.mapPath+".cache");
+  state.mapCached=0;
+ }
+ //viewport()->update();
 }
 
 void TMapView::setDelayMetro(int delay)
@@ -1690,7 +1775,7 @@ void TMapView::saveToFile()
 {
  QFileDialog saveDialog;
  QString filter,fileName=saveDialog.getSaveFileName(this,
- tr("Save file"), ".",
+ tr("Save file"), params.appPath,
  "JPG (*.jpg);;PNG (*.png);;TIF (*.tif);;BMP (*.bmp);;PPM (*.ppm);;XBM (*.xbm);;XPM (*.xpm)",&filter);
  if(fileName.isEmpty()) return;
 
